package xapi-backtrace

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Backtrace.V2Source

Sourceval with_backtraces : finally:(('a, exn * t) result -> 'a) -> (unit -> 'a) -> 'a

with_backtraces thread finally Allows backtraces to be recorded within thread. finally is executed whenever thread finishes, this allows users to use the stacktrace before it's dropped from the cache, for example, to log it.